@@ -7,15 +7,14 @@ suite = Tests()
 @suite.test
 def eval():
     value = 1 + 1
-    valgen = (v for v in [value])
 
     samples = {
-        'isinstance(value, int)': 'isinstance(2, int)',
-        'value == int("2")': "(2 == int('2'))",
+        'isinstance(value, int)': 'True',
+        'value == int("2")': "(2 == 2)",
+        'type(value).__name__': "'int'",
         'value == 5 - 3': '(2 == 2)',
         '{"value": value}': "{'value': 2}",
-        '[valgen.next() for _ in [value]] == [v for v in [value]]':
-            '([2] == [2])',
+        '[v for v in [value]]': '[2]',
     }
 
     for expr, result in samples.iteritems():
